#Key concepts - index

Here we present some key concepts to understand how agent services work internally. More concretely:

  * The section [autonomous economic agents](aea.md) presents an overview of the main components of an agent. It is an excerpt of the {{open_aea_doc}}.
  * The section about [finite-state machines](fsm.md) briefly reviews their main concepts through an example.
  * The section about the [Application Blockchain Interface](abci.md) discusses the interface used by agent services to communicate with the local blockchain.
  * The main section is devoted to [FSM Apps](fsm_app_introduction.md), which is the core component of an agent service which implements its business logic.
  * Finally, we also present some considerations about the [threat model](threat_model.md) of agent services.
